=====
racpy
=====


.. image:: https://img.shields.io/pypi/v/racpy.svg
        :target: https://pypi.python.org/pypi/racpy

.. image:: https://img.shields.io/travis/reese3928/racpy.svg
        :target: https://travis-ci.com/reese3928/racpy

.. image:: https://readthedocs.org/projects/racpy/badge/?version=latest
        :target: https://racpy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/reese3928/racpy/shield.svg
     :target: https://pyup.io/repos/github/reese3928/racpy/
     :alt: Updates



RNASeq Age Calculation in Python


* Free software: MIT license
* Documentation: https://racpy.readthedocs.io.


Features
--------

This is the Python verion of our proposed multi-tissue transcriptional age calculator.

* The RNAAgeCalc paper can be found here https://doi.org/10.1371/journal.pone.0237006.
* The Python package can be found here https://pypi.org/project/racpy.
* The Python package documentation can be found here https://racpy.readthedocs.io.
* An interactive Shiny App can be found here https://xuren2120.shinyapps.io/RNAAgeCalcshiny/.    
* The Shiny App demo can be found here http://www.ams.sunysb.edu/~pfkuan/RNAAgeCalc/instructions.html.  
* The R version can be found here https://bioconductor.org/packages/release/bioc/html/RNAAgeCalc.html.   

Authors
--------

* `Xu Ren <https://github.com/reese3928>`__ <xuren2120@gmail.com>
* `Pei Fen Kuan <http://www.ams.sunysb.edu/~pfkuan/>`__ <peifen.kuan@stonybrook.edu>

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

Dependencies scanned by PyUp.io

Citation
--------
Ren, X., & Kuan, P. F. (2020). RNAAgeCalc: A multi-tissue transcriptional age calculator. PloS one, 15(8), e0237006. 

| @article{ren2020rnaagecalc, 
| title={RNAAgeCalc: A multi-tissue transcriptional age calculator},    
| author={Ren, Xu and Kuan, Pei-Fen},    
| journal={PLOS ONE},    
| volume={15},    
| number={8},    
| pages={1-21},    
| year={2020},    
| publisher={Public Library of Science}    
| }